@@ -174,7 +174,8 @@ empathy_contact_information_dialog_show (EmpathyContact *contact,
 	dialog = gtk_dialog_new ();
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Edit Contact Information"));
+	gtk_window_set_title (GTK_WINDOW (dialog),
+		empathy_contact_get_name (contact));
 
 	/* Close button */
 	button = gtk_button_new_with_label (GTK_STOCK_CLOSE);
