@@ -63,6 +63,8 @@ typedef struct {
 	gboolean                    show_active;
 	EmpathyContactListStoreSort sort_criterium;
 	guint                       inhibit_active;
+	guint                       setup_idle_id;
+	gboolean                    dispose_has_run;
 } EmpathyContactListStorePriv;
 
 typedef struct {
@@ -83,7 +85,7 @@ typedef struct {
 	gboolean                remove;
 } ShowActiveData;
 
-static void             contact_list_store_finalize                  (GObject                       *object);
+static void             contact_list_store_dispose                  (GObject                       *object);
 static void             contact_list_store_get_property              (GObject                       *object,
 								      guint                          param_id,
 								      GValue                        *value,
@@ -193,6 +195,7 @@ contact_list_store_iface_setup (gpointer user_data)
 	}
 	g_list_free (contacts);
 
+	priv->setup_idle_id = 0;
 	return FALSE;
 }
 
@@ -206,7 +209,7 @@ contact_list_store_set_contact_list (EmpathyContactListStore *store,
 	priv->list = g_object_ref (list_iface);
 
 	/* Let a chance to have all properties set before populating */
-	g_idle_add (contact_list_store_iface_setup, store);
+	priv->setup_idle_id = g_idle_add (contact_list_store_iface_setup, store);
 }
 
 static void
@@ -214,7 +217,7 @@ empathy_contact_list_store_class_init (EmpathyContactListStoreClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	object_class->finalize = contact_list_store_finalize;
+	object_class->dispose = contact_list_store_dispose;
 	object_class->get_property = contact_list_store_get_property;
 	object_class->set_property = contact_list_store_set_property;
 
@@ -286,11 +289,15 @@ empathy_contact_list_store_init (EmpathyContactListStore *store)
 }
 
 static void
-contact_list_store_finalize (GObject *object)
+contact_list_store_dispose (GObject *object)
 {
 	EmpathyContactListStorePriv *priv = GET_PRIV (object);
 	GList                       *contacts, *l;
 
+	if (priv->dispose_has_run)
+		return;
+	priv->dispose_has_run = TRUE;
+
 	contacts = empathy_contact_list_get_members (priv->list);
 	for (l = contacts; l; l = l->next) {
 		g_signal_handlers_disconnect_by_func (l->data,
@@ -313,7 +320,11 @@ contact_list_store_finalize (GObject *object)
 		g_source_remove (priv->inhibit_active);
 	}
 
-	G_OBJECT_CLASS (empathy_contact_list_store_parent_class)->finalize (object);
+	if (priv->setup_idle_id != 0) {
+		g_source_remove (priv->setup_idle_id);
+	}
+
+	G_OBJECT_CLASS (empathy_contact_list_store_parent_class)->dispose (object);
 }
 
 static void
@@ -878,7 +889,6 @@ contact_list_store_add_contact (EmpathyContactListStore *store,
 	}
 	/* If no groups just add it at the top level. */
 	if (!groups) {
-		GtkTreeIter iter;
 		GtkTreeModel *model = GTK_TREE_MODEL (store);
 
 		if (gtk_tree_model_get_iter_first (model, &iter)) do {
@@ -1182,19 +1192,19 @@ contact_list_store_contact_set_active (EmpathyContactListStore *store,
 static ShowActiveData *
 contact_list_store_contact_active_new (EmpathyContactListStore *store,
 				       EmpathyContact          *contact,
-				       gboolean                remove)
+				       gboolean                remove_)
 {
 	ShowActiveData *data;
 
 	DEBUG ("Contact:'%s' now active, and %s be removed",
 		empathy_contact_get_name (contact),
-		remove ? "WILL" : "WILL NOT");
+		remove_ ? "WILL" : "WILL NOT");
 
 	data = g_slice_new0 (ShowActiveData);
 
 	data->store = g_object_ref (store);
 	data->contact = g_object_ref (contact);
-	data->remove = remove;
+	data->remove = remove_;
 
 	return data;
 }
