@@ -35,9 +35,11 @@
 
 #include <telepathy-glib/util.h>
 
+#include <libempathy/empathy-connectivity.h>
 #include <libempathy/empathy-idle.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-status-presets.h>
+#include <libempathy/empathy-account-manager.h>
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
 #include <libempathy/empathy-debug.h>
@@ -98,6 +100,7 @@ typedef enum  {
 
 typedef struct {
 	EmpathyIdle *idle;
+	EmpathyConnectivity *connectivity;
 
 	gboolean     editing_status;
 	int          block_set_editing;
@@ -110,6 +113,8 @@ typedef struct {
 	TpConnectionPresenceType   flash_state_1;
 	TpConnectionPresenceType   flash_state_2;
 	guint        flash_timeout_id;
+
+	EmpathyAccountManager *account_manager;
 } EmpathyPresenceChooserPriv;
 
 /* States to be listed in the menu.
@@ -301,7 +306,7 @@ presence_chooser_is_preset (EmpathyPresenceChooser *self)
 
 	g_list_free (presets);
 
-	DEBUG ("is_preset(%i, %s) = %i\n", state, status, match);
+	DEBUG ("is_preset(%i, %s) = %i", state, status, match);
 
 	return match;
 }
@@ -409,7 +414,7 @@ mc_set_custom_state (EmpathyPresenceChooser *self)
 	/* update the status with MC */
 	status = gtk_entry_get_text (GTK_ENTRY (entry));
 
-	DEBUG ("Sending state to MC-> %d (%s)\n", priv->state, status);
+	DEBUG ("Sending state to MC-> %d (%s)", priv->state, status);
 
 	empathy_idle_set_presence (priv->idle, priv->state, status);
 }
@@ -474,12 +479,12 @@ presence_chooser_entry_icon_release_cb (EmpathyPresenceChooser *self,
 
 		if (presence_chooser_is_preset (self)) {
 			/* remove the entry */
-			DEBUG ("REMOVING PRESET (%i, %s)\n", state, status);
+			DEBUG ("REMOVING PRESET (%i, %s)", state, status);
 			empathy_status_presets_remove (state, status);
 		}
 		else {
 			/* save the entry */
-			DEBUG ("SAVING PRESET (%i, %s)\n", state, status);
+			DEBUG ("SAVING PRESET (%i, %s)", state, status);
 			empathy_status_presets_set_last (state, status);
 		}
 
@@ -669,7 +674,7 @@ presence_chooser_entry_focus_out_idle_cb (gpointer user_data)
 	EmpathyPresenceChooser *chooser;
 	GtkWidget *entry;
 
-	DEBUG ("Autocommiting status message\n");
+	DEBUG ("Autocommiting status message");
 
 	chooser = EMPATHY_PRESENCE_CHOOSER (user_data);
 	entry = gtk_bin_get_child (GTK_BIN (chooser));
@@ -709,6 +714,49 @@ presence_chooser_entry_focus_out_cb (EmpathyPresenceChooser *chooser,
 	return FALSE;
 }
 
+static void
+presence_chooser_update_sensitivity (EmpathyPresenceChooser *chooser)
+{
+	EmpathyPresenceChooserPriv *priv = GET_PRIV (chooser);
+	gboolean sensitive = FALSE;
+	GList *accounts, *l;
+
+	accounts = empathy_account_manager_dup_accounts (priv->account_manager);
+
+	for (l = accounts ; l != NULL ; l = g_list_next (l)) {
+		EmpathyAccount *a = EMPATHY_ACCOUNT (l->data);
+
+		if (empathy_account_is_enabled (a))
+			sensitive = TRUE;
+
+		g_object_unref (a);
+	}
+
+	g_list_free (accounts);
+
+	if (!empathy_connectivity_is_online (priv->connectivity))
+		sensitive = FALSE;
+
+	gtk_widget_set_sensitive (GTK_WIDGET (chooser), sensitive);
+}
+
+static void
+presence_chooser_account_manager_account_changed_cb (
+	EmpathyAccountManager *manager,
+	EmpathyAccount *account,
+	EmpathyPresenceChooser *chooser)
+{
+	presence_chooser_update_sensitivity (chooser);
+}
+
+static void
+presence_chooser_connectivity_state_change (EmpathyConnectivity *connectivity,
+					    gboolean new_online,
+					    EmpathyPresenceChooser *chooser)
+{
+	presence_chooser_update_sensitivity (chooser);
+}
+
 static void
 empathy_presence_chooser_init (EmpathyPresenceChooser *chooser)
 {
@@ -773,13 +821,36 @@ empathy_presence_chooser_init (EmpathyPresenceChooser *chooser)
 
 	priv->idle = empathy_idle_dup_singleton ();
 	presence_chooser_presence_changed_cb (chooser);
-	g_signal_connect_swapped (priv->idle, "notify",
+	g_signal_connect_swapped (priv->idle, "notify::state",
 		G_CALLBACK (presence_chooser_presence_changed_cb),
 		chooser);
 
+	priv->account_manager = empathy_account_manager_dup_singleton ();
+
+	empathy_signal_connect_weak (priv->account_manager, "account-created",
+		G_CALLBACK (presence_chooser_account_manager_account_changed_cb),
+		G_OBJECT (chooser));
+	empathy_signal_connect_weak (priv->account_manager, "account-deleted",
+		G_CALLBACK (presence_chooser_account_manager_account_changed_cb),
+		G_OBJECT (chooser));
+	empathy_signal_connect_weak (priv->account_manager, "account-enabled",
+		G_CALLBACK (presence_chooser_account_manager_account_changed_cb),
+		G_OBJECT (chooser));
+	empathy_signal_connect_weak (priv->account_manager, "account-disabled",
+		G_CALLBACK (presence_chooser_account_manager_account_changed_cb),
+		G_OBJECT (chooser));
+
 	/* FIXME: this string sucks */
 	gtk_widget_set_tooltip_text (GTK_WIDGET (chooser),
 		_("Set your presence and current status"));
+
+	priv->connectivity = empathy_connectivity_dup_singleton ();
+	empathy_signal_connect_weak (priv->connectivity,
+		"state-change",
+		G_CALLBACK (presence_chooser_connectivity_state_change),
+		G_OBJECT (chooser));
+
+	presence_chooser_update_sensitivity (chooser);
 }
 
 static void
@@ -797,11 +868,16 @@ presence_chooser_finalize (GObject *object)
 		g_source_remove (priv->focus_out_idle_source);
 	}
 
+	if (priv->account_manager != NULL)
+		g_object_unref (priv->account_manager);
+
 	g_signal_handlers_disconnect_by_func (priv->idle,
 					      presence_chooser_presence_changed_cb,
 					      object);
 	g_object_unref (priv->idle);
 
+	g_object_unref (priv->connectivity);
+
 	G_OBJECT_CLASS (empathy_presence_chooser_parent_class)->finalize (object);
 }
 
@@ -832,6 +908,7 @@ presence_chooser_presence_changed_cb (EmpathyPresenceChooser *chooser)
 	GtkTreeModel               *model;
 	GtkTreeIter                 iter;
 	gboolean valid, match_state = FALSE, match = FALSE;
+	GtkWidget                  *entry;
 
 	priv = GET_PRIV (chooser);
 
@@ -901,6 +978,10 @@ presence_chooser_presence_changed_cb (EmpathyPresenceChooser *chooser)
 	else {
 		presence_chooser_flash_stop (chooser, state);
 	}
+
+	entry = gtk_bin_get_child (GTK_BIN (chooser));
+	gtk_editable_set_editable (GTK_EDITABLE (entry),
+	    state != TP_CONNECTION_PRESENCE_TYPE_OFFLINE);
 }
 
 static gboolean
@@ -1049,6 +1130,7 @@ presence_chooser_menu_add_item (GtkWidget   *menu,
 	gtk_widget_show (image);
 
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
+	gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (item), TRUE);
 	gtk_widget_show (item);
 
 	g_object_set_data_full (G_OBJECT (item),
