@@ -49,6 +49,8 @@ static GDebugKey keys[] = {
   { "Ft", EMPATHY_DEBUG_FT },
   { "Location", EMPATHY_DEBUG_LOCATION },
   { "Other", EMPATHY_DEBUG_OTHER },
+  { "Connectivity", EMPATHY_DEBUG_CONNECTIVITY },
+  { "ImportMc4Accounts", EMPATHY_DEBUG_IMPORT_MC4_ACCOUNTS },
   { 0, }
 };
 
