@@ -215,12 +215,23 @@ idle_session_status_changed_cb (DBusGProxy    *gs_proxy,
 			new_status = priv->status;
 		}
 
-		DEBUG ("Restoring state to %d, reset status to %s",
-			priv->away_saved_state, new_status);
+		/* Only try and set the presence if the away saved state is not
+		 * unset. This is an odd case because it means that the session
+		 * didn't notify us of the state change to idle, and as a
+		 * result, we couldn't save the current state at that time.
+		 */
+		if (priv->away_saved_state != TP_CONNECTION_PRESENCE_TYPE_UNSET) {
+			DEBUG ("Restoring state to %d, reset status to %s",
+				priv->away_saved_state, new_status);
 
-		empathy_idle_set_presence (idle,
-					   priv->away_saved_state,
-					   new_status);
+			empathy_idle_set_presence (idle,
+						   priv->away_saved_state,
+						   new_status);
+		} else {
+			DEBUG ("Away saved state is unset. This means that we "
+			       "weren't told when the session went idle. "
+			       "As a result, I'm not trying to set presence");
+		}
 
 		priv->away_saved_state = TP_CONNECTION_PRESENCE_TYPE_UNSET;
 	}
@@ -409,6 +420,27 @@ empathy_idle_class_init (EmpathyIdleClass *klass)
 	g_type_class_add_private (object_class, sizeof (EmpathyIdlePriv));
 }
 
+static void
+account_manager_ready_cb (EmpathyAccountManager *account_manager,
+			  GParamSpec *pspec,
+			  EmpathyIdle *idle)
+{
+	EmpathyIdlePriv *priv;
+	TpConnectionPresenceType state;
+	gchar *status, *status_message;
+
+	priv = GET_PRIV (idle);
+
+	state = empathy_account_manager_get_global_presence (priv->manager,
+		&status, &status_message);
+
+	idle_presence_changed_cb (account_manager, state, status,
+		status_message, idle);
+
+	g_free (status);
+	g_free (status_message);
+}
+
 static void
 empathy_idle_init (EmpathyIdle *idle)
 {
@@ -419,8 +451,14 @@ empathy_idle_init (EmpathyIdle *idle)
 	priv->is_idle = FALSE;
 
 	priv->manager = empathy_account_manager_dup_singleton ();
-	priv->state = empathy_account_manager_get_global_presence (priv->manager,
-		NULL, &priv->status);
+
+	if (empathy_account_manager_is_ready (priv->manager)) {
+		priv->state = empathy_account_manager_get_global_presence (priv->manager,
+			NULL, &priv->status);
+	} else {
+		g_signal_connect (priv->manager, "notify::ready",
+			G_CALLBACK (account_manager_ready_cb), idle);
+	}
 
 
 	g_signal_connect (priv->manager, "global-presence-changed",
@@ -570,17 +608,19 @@ empathy_idle_set_presence (EmpathyIdle *idle,
 		status = NULL;
 	}
 
-	if (!empathy_connectivity_is_online (priv->connectivity)) {
+	if (state != TP_CONNECTION_PRESENCE_TYPE_OFFLINE &&
+			!empathy_connectivity_is_online (priv->connectivity)) {
 		DEBUG ("Empathy is not online");
 
+		priv->saved_state = state;
 		if (tp_strdiff (priv->status, status)) {
-			g_free (priv->status);
-			priv->status = NULL;
+			g_free (priv->saved_status);
+			priv->saved_status = NULL;
 			if (!EMP_STR_EMPTY (status)) {
-				priv->status = g_strdup (status);
+				priv->saved_status = g_strdup (status);
 			}
-			g_object_notify (G_OBJECT (idle), "status");
 		}
+		return;
 	}
 
 	empathy_idle_do_set_presence (idle, state, status);
