@@ -780,6 +780,10 @@ tp_chat_check_if_ready (EmpathyTpChat *chat)
 									   tp_chat_state_changed_cb,
 									   NULL, NULL,
 									   G_OBJECT (chat), NULL);
+	tp_cli_channel_interface_chat_state_connect_to_chat_state_changed (priv->channel,
+									   tp_chat_state_changed_cb,
+									   NULL, NULL,
+									   G_OBJECT (chat), NULL);
 	priv->ready = TRUE;
 	g_object_notify (G_OBJECT (chat), "ready");
 }
@@ -878,7 +882,7 @@ tp_chat_got_added_contacts_cb (EmpathyTpContactFactory *factory,
 static EmpathyContact *
 chat_lookup_contact (EmpathyTpChat *chat,
 		     TpHandle       handle,
-		     gboolean       remove)
+		     gboolean       remove_)
 {
 	EmpathyTpChatPriv *priv = GET_PRIV (chat);
 	GList *l;
@@ -890,7 +894,7 @@ chat_lookup_contact (EmpathyTpChat *chat,
 			continue;
 		}
 
-		if (remove) {
+		if (remove_) {
 			/* Caller takes the reference. */
 			priv->members = g_list_delete_link (priv->members, l);
 		} else {
@@ -1247,10 +1251,19 @@ const gchar *
 empathy_tp_chat_get_id (EmpathyTpChat *chat)
 {
 	EmpathyTpChatPriv *priv = GET_PRIV (chat);
+	const gchar *id;
+
 
 	g_return_val_if_fail (EMPATHY_IS_TP_CHAT (chat), NULL);
 
-	return tp_channel_get_identifier (priv->channel);
+	id = tp_channel_get_identifier (priv->channel);
+	if (!EMP_STR_EMPTY (id))
+		return id;
+	else if (priv->remote_contact)
+		return empathy_contact_get_id (priv->remote_contact);
+	else
+		return NULL;
+
 }
 
 EmpathyContact *
