@@ -620,8 +620,9 @@ empathy_call_window_setup_self_frame (GstBus *bus, EmpathyCallWindow *self)
   gst_object_ref (priv->audio_input);
   gst_object_sink (priv->audio_input);
 
-  g_signal_connect (priv->audio_input, "peak-level-changed",
-    G_CALLBACK (empathy_call_window_audio_input_level_changed_cb), self);
+  empathy_signal_connect_weak (priv->audio_input, "peak-level-changed",
+    G_CALLBACK (empathy_call_window_audio_input_level_changed_cb),
+    G_OBJECT (self));
 }
 
 static void
@@ -942,7 +943,7 @@ empathy_call_window_setup_avatars (EmpathyCallWindow *self,
       factory = empathy_tp_contact_factory_dup_singleton (connection);
       empathy_tp_contact_factory_get_from_handle (factory,
           tp_connection_get_self_handle (connection),
-          empathy_call_window_got_self_contact_cb, self, NULL, NULL);
+          empathy_call_window_got_self_contact_cb, self, NULL, G_OBJECT (self));
 
       g_object_unref (factory);
     }
@@ -1087,10 +1088,9 @@ empathy_call_window_dispose (GObject *object)
     {
       g_signal_handlers_disconnect_by_func (call,
         empathy_call_window_video_stream_changed_cb, object);
+      g_object_unref (call);
     }
 
-  g_object_unref (call);
-
   if (priv->handler != NULL)
     g_object_unref (priv->handler);
   priv->handler = NULL;
@@ -1447,13 +1447,13 @@ empathy_call_window_update_timer (gpointer user_data)
   EmpathyCallWindow *self = EMPATHY_CALL_WINDOW (user_data);
   EmpathyCallWindowPriv *priv = GET_PRIV (self);
   gchar *str;
-  gdouble time;
+  gdouble time_;
 
-  time = g_timer_elapsed (priv->timer, NULL);
+  time_ = g_timer_elapsed (priv->timer, NULL);
 
   /* Translators: number of minutes:seconds the caller has been connected */
-  str = g_strdup_printf (_("Connected — %d:%02dm"), (int) time / 60,
-    (int) time % 60);
+  str = g_strdup_printf (_("Connected — %d:%02dm"), (int) time_ / 60,
+    (int) time_ % 60);
   empathy_call_window_status_message (self, str);
   g_free (str);
 
