@@ -103,16 +103,7 @@ dispatch_cb (EmpathyDispatcher *dispatcher,
         (empathy_dispatch_operation_get_channel_wrapper (operation));
 
       id = empathy_tp_chat_get_id (tp_chat);
-      if (!id)
-        {
-          EmpathyContact *contact;
-
-          contact = empathy_tp_chat_get_remote_contact (tp_chat);
-          if (contact)
-            id = empathy_contact_get_id (contact);
-        }
-
-      if (id)
+      if (!EMP_STR_EMPTY (id))
         {
           EmpathyAccountManager *manager;
           TpConnection *connection;
@@ -127,9 +118,16 @@ dispatch_cb (EmpathyDispatcher *dispatcher,
         }
 
       if (chat)
-        empathy_chat_set_tp_chat (chat, tp_chat);
+        {
+          empathy_chat_set_tp_chat (chat, tp_chat);
+        }
       else
-        chat = empathy_chat_new (tp_chat);
+        {
+          chat = empathy_chat_new (tp_chat);
+          /* empathy_chat_new returns a floating reference as EmpathyChat is
+           * a GtkWidget. This reference will be taken by a container
+           * (a GtkNotebook) when we'll call empathy_chat_window_present_chat */
+        }
 
       empathy_chat_window_present_chat (chat);
 
@@ -672,7 +670,7 @@ setup_dispatcher (void)
     "org.freedesktop.Telepathy.Channel.Interface.MediaSignalling/gtalk-p2p",
     NULL };
   GHashTable *asv;
-  int i;
+  guint i;
 
   /* Setup the basic Client.Handler that matches our client filter */
   filters = g_ptr_array_new ();
@@ -701,6 +699,27 @@ setup_dispatcher (void)
       g_ptr_array_add (filters, asv);
     }
 
+  asv = tp_asv_new (
+        TP_IFACE_CHANNEL ".ChannelType",
+          G_TYPE_STRING, TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA,
+        TP_IFACE_CHANNEL ".TargetHandleType",
+          G_TYPE_INT, TP_HANDLE_TYPE_CONTACT,
+        TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA ".InitialAudio",
+          G_TYPE_BOOLEAN, TRUE,
+        NULL);
+  g_ptr_array_add (filters, asv);
+
+  asv = tp_asv_new (
+        TP_IFACE_CHANNEL ".ChannelType",
+          G_TYPE_STRING, TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA,
+        TP_IFACE_CHANNEL ".TargetHandleType",
+          G_TYPE_INT, TP_HANDLE_TYPE_CONTACT,
+        TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA ".InitialVideo",
+          G_TYPE_BOOLEAN, TRUE,
+        NULL);
+  g_ptr_array_add (filters, asv);
+
+
   empathy_dispatcher_add_handler (d, PACKAGE_NAME"MoreThanMeetsTheEye",
     filters, capabilities);
 
@@ -822,9 +841,9 @@ main (int argc, char *argv[])
         0, G_OPTION_ARG_NONE, &no_connect,
         N_("Don't connect on startup"),
         NULL },
-      { "hide-contact-list", 'h',
+      { "start-hidden", 'h',
         0, G_OPTION_ARG_NONE, &start_hidden,
-        N_("Don't show the contact list on startup"),
+        N_("Don't display the contact list or any other dialogs on startup"),
         NULL },
       { "accounts", 'a',
         0, G_OPTION_ARG_NONE, &account_dialog_only,
